@@ -2,7 +2,5 @@ from dciclient.v1 import utils
 
 
 def print_response(response, format, verbose):
-    if response.status_code == 204:
-        utils.print_json({"status_code": 204, "message": "resource deleted."})
-    else:
+    if response and response.status_code != 204:
         utils.format_output(response, format, verbose=verbose)
